''' ["essential nutrients"].measures { "mass + mass equivalents": { "per recipe": { "grams": { "fraction string": "10" } } }, "biological activity": { "per recipe": { "IU": { "fraction string": "0" } } }, "energy": { "per recipe": { "calories": { "fraction string": "0" }, "joules": { "fraction string": "0" } } } } ''' ''' Modify these "ingredient measures". grove [0].measures: { "mass + mass equivalents": { "per recipe": { "grams": { "fraction string": "10" } } } } ''' ''' Don't modify these. This one says "per package" so don't modify it according to the amount. natures [0].measures: { "mass + mass equivalents": { "mass + mass equivalents": { "per package": { "listed": [ "12.984", "mg" ], "grams": { "decimal string": "0.013", "fraction string": "1461913475040736643/112589990684262400000" } } } } } '''